pub struct ResponseHeader { /* private fields */ }Expand description
RTSP response header.
Implementations
Sourceimpl ResponseHeader
impl ResponseHeader
Sourcepub fn status_code(&self) -> u16
pub fn status_code(&self) -> u16
Get the status code.
Sourcepub fn status_message(&self) -> &StatusMessage
pub fn status_message(&self) -> &StatusMessage
Get the status message.
Sourcepub fn get_all_header_fields(&self) -> Iter<'_> ⓘ
pub fn get_all_header_fields(&self) -> Iter<'_> ⓘ
Get all header fields.
Sourcepub fn get_header_fields<'a, N>(&'a self, name: &'a N) -> FieldIter<'a> ⓘ
pub fn get_header_fields<'a, N>(&'a self, name: &'a N) -> FieldIter<'a> ⓘ
Get header fields corresponding to a given name.
Sourcepub fn get_header_field<'a, N>(&'a self, name: &'a N) -> Option<&'a HeaderField>
pub fn get_header_field<'a, N>(&'a self, name: &'a N) -> Option<&'a HeaderField>
Get the last header field of a given name.
Sourcepub fn get_header_field_value<'a, N>(
&'a self,
name: &'a N,
) -> Option<&'a HeaderFieldValue>
pub fn get_header_field_value<'a, N>( &'a self, name: &'a N, ) -> Option<&'a HeaderFieldValue>
Get value of the last header field with a given name.